Commit: 52c5365c002acbaa45be28928ab117b394e3d380
Author: gaiaclary
Date:   Fri Dec 13 15:29:50 2013 +0100
http://developer.blender.org/rB52c5365c002acbaa45be28928ab117b394e3d380

Changed label to use UV Maps instead of UV Layouts

===================================================================

M       release/scripts/startup/bl_operators/object.py

===================================================================

diff --git a/release/scripts/startup/bl_operators/object.py 
b/release/scripts/startup/bl_operators/object.py
index bcc8d44..e5e53d6 100644
--- a/release/scripts/startup/bl_operators/object.py
+++ b/release/scripts/startup/bl_operators/object.py
@@ -474,10 +474,10 @@ class ShapeTransfer(Operator):
 
 
 class JoinUVs(Operator):
     """Transfer UV Layouts from active to selected objects """ \
     """(needs matching geometry)"""
     bl_idname = "object.join_uvs"
-    bl_label = "Transfer UV Layouts"
+    bl_label = "Transfer UV Maps"
 
     @classmethod
     def poll(cls, context):
@@ -474,10 +474,10 @@ class ShapeTransfer(Operator):
 
 class JoinUVs(Operator):
-    """Transfer UV Layouts from active to selected objects """ \
+    """Transfer UV Maps from active to selected objects """ \
     """(needs matching geometry)"""
     bl_idname = "object.join_uvs"

_______________________________________________
Bf-blender-cvs mailing list
[email protected]
http://lists.blender.org/mailman/listinfo/bf-blender-cvs

Reply via email to